/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geometry;

import java.util.Collection;
import org.openide.WizardDescriptor;
import org.openide.loaders.DataObject;
import org.openide.util.Lookup;

/**
 * Classes implementing this interface are able to display a visual preview of a geometry file.
 * @author Gerben Feenstra
 */
public interface GeoImportSupport{

    boolean supports(DataObject dataObject);
    
    PreviewPanel getPreviewPanel(DataObject dataObject);
    
    
    
    public static class Util {
        
        /**
        * Find a suitable GeoImportSupport implementation
        * @param dataObject
        * @return 
        */
        public static GeoImportSupport findImportSupportFor(DataObject dataObject){
            Collection<? extends GeoImportSupport> supporters = Lookup.getDefault().lookupAll(GeoImportSupport.class);
            for(GeoImportSupport geoImportSupport : supporters){
                if(geoImportSupport.supports(dataObject)){
                    return geoImportSupport;
                }
            }
            return null;
        }            
        
        /**
        * Find a suitable Preview panel for specified Geo dataObject.
        * @param dataObject
        * @return 
        */
        public static WizardDescriptor.Panel findPreviewPanelFor(DataObject dataObject){
            Collection<? extends GeoImportSupport> supporters = Lookup.getDefault().lookupAll(GeoImportSupport.class);
            for(GeoImportSupport geoImportSupport : supporters){
                if(geoImportSupport.supports(dataObject)){
                    return geoImportSupport.getPreviewPanel(dataObject);
                }
            }
            return null;
        }       
    }
}
