/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.geometry.wizard;

import org.apache.commons.lang.StringUtils;
import java.awt.Color;
import java.util.List;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.border.EmptyBorder;
import javax.swing.table.DefaultTableModel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.geometry.model.Shape;
import org.openide.util.NbBundle;

/**
 * Panel which displays a summary of all the imported fields.
 * @author Merijn Zengers
 */
@NbBundle.Messages({"ImportShapeSummaryPanel_shape_id_table_comumn= ID",
                    "ImportShapeSummaryPanel_shape_name_table_comumn= Name",
                    "ImportShapeSummaryPanel_shape_value_table_comumn= Value",
                    "ImportShapeSummaryPanel_summary_text=You have chosen to import the following shapes: "})
public class ImportShapeSummaryPanel extends JPanel{
    
    private DefaultTableModel tableModel;
    private JTable importedtable;
    
    public ImportShapeSummaryPanel(){
        this.setLayout(new MigLayout("wrap 1"));
        
        JLabel summaryText = new JLabel(Bundle.ImportShapeSummaryPanel_summary_text());
        
        this.add(summaryText);
        tableModel = new DefaultTableModel();
        importedtable = new JTable(tableModel);
        importedtable.setBorder(new EmptyBorder(0,0,0,0));
        importedtable.setBackground(Color.white);
        
        JScrollPane importedTableScrolPane = new JScrollPane(importedtable);
        importedTableScrolPane.setBackground(Color.white);
        importedTableScrolPane.setBorder(new EmptyBorder(0, 0, 0, 0));
        importedTableScrolPane.getViewport().setBackground(Color.white);
        this.add(importedTableScrolPane);
                
        
    }
    
    public void setImportedShapes(List<Shape> shapes){
        //First determine if value and name are set.
        //We only want to display columns who are set
        boolean value = false , name = false;
        for(Shape shape : shapes){
            if(shape.getValue() != null){
                value = true;
            }
            if(shape.getName() != null && !shape.getName().equals("")){
               
                name = true;
            }
            if(name && value){
                break;
            }
        }
        
        tableModel.setColumnCount(0);
        int rowCount = tableModel.getRowCount() - 1;
        for(int i = rowCount; i >= 0; i--){
            tableModel.removeRow(i);
        }
        
        tableModel.addColumn(Bundle.ImportShapeSummaryPanel_shape_id_table_comumn());
        if(name){
            tableModel.addColumn(Bundle.ImportShapeSummaryPanel_shape_name_table_comumn());
        }
        if(value){
            tableModel.addColumn(Bundle.ImportShapeSummaryPanel_shape_value_table_comumn());
        }
        for(Shape shape : shapes){
            int length = value && name ? 3 : value || name ? 2 : 1;
            Object[] rowData = new Object[length];
            rowData[0] = shape.getId();
            if(name) {
                String shapeName = shape.getName();
                shape.setName(shapeName.replace("\\" ,  ""));
            }
            
            if(value && name){
                rowData[1] = shape.getName();
                rowData[2] = shape.getValue();
            } else if(name){
                rowData[1] = shape.getName();
            } else if(value){
                rowData[1] = shape.getValue();
            }
            tableModel.addRow(rowData);
        }
        
        
    }
}
